# libpythonprobr
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link do curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.org/brjatoba92/libpythonprobr.svg?branch=master)](https://travis-ci.org/brjatoba92/libpythonprobr)
[![Updates](https://pyup.io/repos/github/brjatoba92/libpythonprobr/shield.svg)](https://pyup.io/repos/github/brjatoba92/libpythonprobr/)
[![Python 3](https://pyup.io/repos/github/brjatoba92/libpythonprobr/python-3-shield.svg)](https://pyup.io/repos/github/brjatoba92/libpythonprobr/)

Versão 3 do Python

Para instalar:

```console
py -3 -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt
```

Para verificar qualidade do código:

```console
flake8
```

Tópicos a serem abordados:
1. Git
2. VirtualEnv
3. Pip
4. PyPi
